pyprocar.core.KPath — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.core.KPath

class pyprocar.core.KPath(knames=None, kticks=None, special_kpoints=None, ngrids=None, has_time_reversal=True)

  Methods

  `KPath.__init__`([knames, kticks, ...]) | The Kpath object to handle labels and ticks for band structure
  `KPath.get_kpoints_transformed`(...) | A method to get the transformed kpoints
  `KPath.get_optimized_kpoints_transformed`(...) | A method to get the optimized kpoints after a transformation
  `KPath.write_to_file`([filename, fmt]) | Write the kpath to a file.

  Attributes

  `KPath.kdistances` | An array with the kdistance along the kpath
  `KPath.nsegments` | The number of band segments
  `KPath.tick_names` | The list of tick names
  `KPath.tick_positions` | The list of tick positions